pub struct MappedErrors { /* private fields */ }Implementations
Sourceimpl MappedErrors
impl MappedErrors
Sourcepub fn error_type(&self) -> ErrorType
pub fn error_type(&self) -> ErrorType
This method returns the error type of the current error.
Sourcepub fn code(&self) -> ErrorCodes
pub fn code(&self) -> ErrorCodes
This method returns the error code key of the current error.
Sourcepub fn has_str_code(&self, code: &str) -> bool
pub fn has_str_code(&self, code: &str) -> bool
This method returns a boolean indicating if the current error is expected or not.
pub fn is_in<T: ToString>(&self, codes: Vec<T>) -> bool
Sourcepub fn with_exp_true(self) -> Self
pub fn with_exp_true(self) -> Self
Dispatches an log error indicating unexpected error.
Sourcepub fn with_previous(self, prev: MappedErrors) -> Self
pub fn with_previous(self, prev: MappedErrors) -> Self
Include previous mapped error in message
Sourcepub fn with_error_type(self, error_type: ErrorType) -> Self
pub fn with_error_type(self, error_type: ErrorType) -> Self
Set the error type of the current error.
Sourcepub fn from_str_msg(msg: String) -> Self
pub fn from_str_msg(msg: String) -> Self
This method returns a new MappedErrors struct from a string.